@@ -30,7 +30,7 @@
 pal_d3 <- function(palette = c("category10", "category20", "category20b", "category20c"), alpha = 1) {
   palette <- match.arg(palette)
 
-  if (alpha > 1L | alpha <= 0L) stop("alpha must be in (0, 1]")
+  if (alpha > 1L || alpha <= 0L) stop("alpha must be in (0, 1]")
 
   raw_cols <- ggsci_db$"d3"[[palette]]
   raw_cols_rgb <- col2rgb(raw_cols)
@@ -93,7 +93,7 @@ pal_d3 <- function(palette = c("category10", "category20", "category20b", "categ
 #' p2 + scale_fill_d3(palette = "category20c")
 scale_color_d3 <- function(palette = c("category10", "category20", "category20b", "category20c"), alpha = 1, ...) {
   palette <- match.arg(palette)
-  discrete_scale("colour", "d3", pal_d3(palette, alpha), ...)
+  discrete_scale("colour", palette = pal_d3(palette, alpha), ...)
 }
 
 #' @export scale_colour_d3
@@ -105,5 +105,5 @@ scale_colour_d3 <- scale_color_d3
 #' @rdname scale_d3
 scale_fill_d3 <- function(palette = c("category10", "category20", "category20b", "category20c"), alpha = 1, ...) {
   palette <- match.arg(palette)
-  discrete_scale("fill", "d3", pal_d3(palette, alpha), ...)
+  discrete_scale("fill", palette = pal_d3(palette, alpha), ...)
 }
