@@ -20,21 +20,20 @@
 #' library("scales")
 #' show_col(pal_rickandmorty("schwifty")(12))
 #' show_col(pal_rickandmorty("schwifty", alpha = 0.6)(12))
-pal_rickandmorty = function (palette = c('schwifty'), alpha = 1) {
+pal_rickandmorty <- function(palette = c("schwifty"), alpha = 1) {
+  palette <- match.arg(palette)
 
-  palette = match.arg(palette)
+  if (alpha > 1L || alpha <= 0L) stop("alpha must be in (0, 1]")
 
-  if (alpha > 1L | alpha <= 0L) stop('alpha must be in (0, 1]')
-
-  raw_cols = ggsci_db$'rickandmorty'[[palette]]
-  raw_cols_rgb = col2rgb(raw_cols)
-  alpha_cols = rgb(
+  raw_cols <- ggsci_db$"rickandmorty"[[palette]]
+  raw_cols_rgb <- col2rgb(raw_cols)
+  alpha_cols <- rgb(
     raw_cols_rgb[1L, ], raw_cols_rgb[2L, ], raw_cols_rgb[3L, ],
     alpha = alpha * 255L, names = names(raw_cols),
-    maxColorValue = 255L)
+    maxColorValue = 255L
+  )
 
   manual_pal(unname(alpha_cols))
-
 }
 
 #' Rick and Morty Color Scales
@@ -57,33 +56,35 @@ pal_rickandmorty = function (palette = c('schwifty'), alpha = 1) {
 #' library("ggplot2")
 #' data("diamonds")
 #'
-#' ggplot(subset(diamonds, carat >= 2.2),
-#'        aes(x = table, y = price, colour = cut)) +
+#' ggplot(
+#'   subset(diamonds, carat >= 2.2),
+#'   aes(x = table, y = price, colour = cut)
+#' ) +
 #'   geom_point(alpha = 0.7) +
 #'   geom_smooth(method = "loess", alpha = 0.1, size = 1, span = 1) +
-#'   theme_bw() + scale_color_rickandmorty()
+#'   theme_bw() +
+#'   scale_color_rickandmorty()
 #'
-#' ggplot(subset(diamonds, carat > 2.2 & depth > 55 & depth < 70),
-#'        aes(x = depth, fill = cut)) +
+#' ggplot(
+#'   subset(diamonds, carat > 2.2 & depth > 55 & depth < 70),
+#'   aes(x = depth, fill = cut)
+#' ) +
 #'   geom_histogram(colour = "black", binwidth = 1, position = "dodge") +
-#'   theme_bw() + scale_fill_rickandmorty()
-scale_color_rickandmorty = function (palette = c('schwifty'), alpha = 1, ...) {
-
-  palette = match.arg(palette)
-  discrete_scale('colour', 'rickandmorty', pal_rickandmorty(palette, alpha), ...)
-
+#'   theme_bw() +
+#'   scale_fill_rickandmorty()
+scale_color_rickandmorty <- function(palette = c("schwifty"), alpha = 1, ...) {
+  palette <- match.arg(palette)
+  discrete_scale("colour", palette = pal_rickandmorty(palette, alpha), ...)
 }
 
 #' @export scale_colour_rickandmorty
 #' @rdname scale_rickandmorty
-scale_colour_rickandmorty = scale_color_rickandmorty
+scale_colour_rickandmorty <- scale_color_rickandmorty
 
 #' @export scale_fill_rickandmorty
 #' @importFrom ggplot2 discrete_scale
 #' @rdname scale_rickandmorty
-scale_fill_rickandmorty = function (palette = c('schwifty'), alpha = 1, ...) {
-
-  palette = match.arg(palette)
-  discrete_scale('fill', 'rickandmorty', pal_rickandmorty(palette, alpha), ...)
-
+scale_fill_rickandmorty <- function(palette = c("schwifty"), alpha = 1, ...) {
+  palette <- match.arg(palette)
+  discrete_scale("fill", palette = pal_rickandmorty(palette, alpha), ...)
 }
