@@ -23,7 +23,7 @@
 pal_startrek <- function(palette = c("uniform"), alpha = 1) {
   palette <- match.arg(palette)
 
-  if (alpha > 1L | alpha <= 0L) stop("alpha must be in (0, 1]")
+  if (alpha > 1L || alpha <= 0L) stop("alpha must be in (0, 1]")
 
   raw_cols <- ggsci_db$"startrek"[[palette]]
   raw_cols_rgb <- col2rgb(raw_cols)
@@ -55,24 +55,26 @@ pal_startrek <- function(palette = c("uniform"), alpha = 1) {
 #' @examples
 #' library("ggplot2")
 #' data("diamonds")
-#' 
+#'
 #' ggplot(
 #'   subset(diamonds, carat >= 2.2),
 #'   aes(x = table, y = price, colour = cut)
 #' ) +
 #'   geom_point(alpha = 0.7) +
 #'   geom_smooth(method = "loess", alpha = 0.1, size = 1, span = 1) +
-#'   theme_bw() + scale_color_startrek()
-#' 
+#'   theme_bw() +
+#'   scale_color_startrek()
+#'
 #' ggplot(
 #'   subset(diamonds, carat > 2.2 & depth > 55 & depth < 70),
 #'   aes(x = depth, fill = cut)
 #' ) +
 #'   geom_histogram(colour = "black", binwidth = 1, position = "dodge") +
-#'   theme_bw() + scale_fill_startrek()
+#'   theme_bw() +
+#'   scale_fill_startrek()
 scale_color_startrek <- function(palette = c("uniform"), alpha = 1, ...) {
   palette <- match.arg(palette)
-  discrete_scale("colour", "startrek", pal_startrek(palette, alpha), ...)
+  discrete_scale("colour", palette = pal_startrek(palette, alpha), ...)
 }
 
 #' @export scale_colour_startrek
@@ -84,5 +86,5 @@ scale_colour_startrek <- scale_color_startrek
 #' @rdname scale_startrek
 scale_fill_startrek <- function(palette = c("uniform"), alpha = 1, ...) {
   palette <- match.arg(palette)
-  discrete_scale("fill", "startrek", pal_startrek(palette, alpha), ...)
+  discrete_scale("fill", palette = pal_startrek(palette, alpha), ...)
 }
