@@ -20,21 +20,20 @@
 #' library("scales")
 #' show_col(pal_ucscgb("default")(26))
 #' show_col(pal_ucscgb("default", alpha = 0.6)(26))
-pal_ucscgb = function (palette = c('default'), alpha = 1) {
+pal_ucscgb <- function(palette = c("default"), alpha = 1) {
+  palette <- match.arg(palette)
 
-  palette = match.arg(palette)
+  if (alpha > 1L || alpha <= 0L) stop("alpha must be in (0, 1]")
 
-  if (alpha > 1L | alpha <= 0L) stop('alpha must be in (0, 1]')
-
-  raw_cols = ggsci_db$'ucscgb'[[palette]]
-  raw_cols_rgb = col2rgb(raw_cols)
-  alpha_cols = rgb(
+  raw_cols <- ggsci_db$"ucscgb"[[palette]]
+  raw_cols_rgb <- col2rgb(raw_cols)
+  alpha_cols <- rgb(
     raw_cols_rgb[1L, ], raw_cols_rgb[2L, ], raw_cols_rgb[3L, ],
     alpha = alpha * 255L, names = names(raw_cols),
-    maxColorValue = 255L)
+    maxColorValue = 255L
+  )
 
   manual_pal(unname(alpha_cols))
-
 }
 
 #' UCSC Genome Browser Color Scales
@@ -57,33 +56,35 @@ pal_ucscgb = function (palette = c('default'), alpha = 1) {
 #' library("ggplot2")
 #' data("diamonds")
 #'
-#' ggplot(subset(diamonds, carat >= 2.2),
-#'        aes(x = table, y = price, colour = cut)) +
+#' ggplot(
+#'   subset(diamonds, carat >= 2.2),
+#'   aes(x = table, y = price, colour = cut)
+#' ) +
 #'   geom_point(alpha = 0.7) +
 #'   geom_smooth(method = "loess", alpha = 0.1, size = 1, span = 1) +
-#'   theme_bw() + scale_color_ucscgb()
+#'   theme_bw() +
+#'   scale_color_ucscgb()
 #'
-#' ggplot(subset(diamonds, carat > 2.2 & depth > 55 & depth < 70),
-#'        aes(x = depth, fill = cut)) +
+#' ggplot(
+#'   subset(diamonds, carat > 2.2 & depth > 55 & depth < 70),
+#'   aes(x = depth, fill = cut)
+#' ) +
 #'   geom_histogram(colour = "black", binwidth = 1, position = "dodge") +
-#'   theme_bw() + scale_fill_ucscgb()
-scale_color_ucscgb = function (palette = c('default'), alpha = 1, ...) {
-
-  palette = match.arg(palette)
-  discrete_scale('colour', 'ucscgb', pal_ucscgb(palette, alpha), ...)
-
+#'   theme_bw() +
+#'   scale_fill_ucscgb()
+scale_color_ucscgb <- function(palette = c("default"), alpha = 1, ...) {
+  palette <- match.arg(palette)
+  discrete_scale("colour", palette = pal_ucscgb(palette, alpha), ...)
 }
 
 #' @export scale_colour_ucscgb
 #' @rdname scale_ucscgb
-scale_colour_ucscgb = scale_color_ucscgb
+scale_colour_ucscgb <- scale_color_ucscgb
 
 #' @export scale_fill_ucscgb
 #' @importFrom ggplot2 discrete_scale
 #' @rdname scale_ucscgb
-scale_fill_ucscgb = function (palette = c('default'), alpha = 1, ...) {
-
-  palette = match.arg(palette)
-  discrete_scale('fill', 'ucscgb', pal_ucscgb(palette, alpha), ...)
-
+scale_fill_ucscgb <- function(palette = c("default"), alpha = 1, ...) {
+  palette <- match.arg(palette)
+  discrete_scale("fill", palette = pal_ucscgb(palette, alpha), ...)
 }
